/*!
 * vue3-auto-logout v1.0.1
 * (c) 2021-2021 Zeffon
 * Released under the MIT License.
 */
/*! js-cookie v3.0.0 | MIT */
/* eslint-disable no-var */
function assign (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];
    for (var key in source) {
      target[key] = source[key];
    }
  }
  return target
}
/* eslint-enable no-var */

/* eslint-disable no-var */
var defaultConverter = {
  read: function (value) {
    return value.replace(/(%[\dA-F]{2})+/gi, decodeURIComponent)
  },
  write: function (value) {
    return encodeURIComponent(value).replace(
      /%(2[346BF]|3[AC-F]|40|5[BDE]|60|7[BCD])/g,
      decodeURIComponent
    )
  }
};
/* eslint-enable no-var */

/* eslint-disable no-var */

function init (converter, defaultAttributes) {
  function set (key, value, attributes) {
    if (typeof document === 'undefined') {
      return
    }

    attributes = assign({}, defaultAttributes, attributes);

    if (typeof attributes.expires === 'number') {
      attributes.expires = new Date(Date.now() + attributes.expires * 864e5);
    }
    if (attributes.expires) {
      attributes.expires = attributes.expires.toUTCString();
    }

    key = encodeURIComponent(key)
      .replace(/%(2[346B]|5E|60|7C)/g, decodeURIComponent)
      .replace(/[()]/g, escape);

    value = converter.write(value, key);

    var stringifiedAttributes = '';
    for (var attributeName in attributes) {
      if (!attributes[attributeName]) {
        continue
      }

      stringifiedAttributes += '; ' + attributeName;

      if (attributes[attributeName] === true) {
        continue
      }

      // Considers RFC 6265 section 5.2:
      // ...
      // 3.  If the remaining unparsed-attributes contains a %x3B (";")
      //     character:
      // Consume the characters of the unparsed-attributes up to,
      // not including, the first %x3B (";") character.
      // ...
      stringifiedAttributes += '=' + attributes[attributeName].split(';')[0];
    }

    return (document.cookie = key + '=' + value + stringifiedAttributes)
  }

  function get (key) {
    if (typeof document === 'undefined' || (arguments.length && !key)) {
      return
    }

    // To prevent the for loop in the first place assign an empty array
    // in case there are no cookies at all.
    var cookies = document.cookie ? document.cookie.split('; ') : [];
    var jar = {};
    for (var i = 0; i < cookies.length; i++) {
      var parts = cookies[i].split('=');
      var value = parts.slice(1).join('=');

      if (value[0] === '"') {
        value = value.slice(1, -1);
      }

      try {
        var foundKey = defaultConverter.read(parts[0]);
        jar[foundKey] = converter.read(value, foundKey);

        if (key === foundKey) {
          break
        }
      } catch (e) {}
    }

    return key ? jar[key] : jar
  }

  return Object.create(
    {
      set: set,
      get: get,
      remove: function (key, attributes) {
        set(
          key,
          '',
          assign({}, attributes, {
            expires: -1
          })
        );
      },
      withAttributes: function (attributes) {
        return init(this.converter, assign({}, this.attributes, attributes))
      },
      withConverter: function (converter) {
        return init(assign({}, this.converter, converter), this.attributes)
      }
    },
    {
      attributes: { value: Object.freeze(defaultAttributes) },
      converter: { value: Object.freeze(converter) }
    }
  )
}

var api = init(defaultConverter, { path: '/' });

function clearCookies() {
    const cookies = document.cookie.split(';');
    for (let i = 0; i < cookies.length; i++) {
        const cookie = cookies[i];
        const eqPos = cookie.indexOf('=');
        const name = eqPos > -1 ? cookie.substr(0, eqPos) : cookie;
        document.cookie = name + '=;expires=Thu, 01 Jan 1970 00:00:00 GMT';
    }
}

const LAST_TIME = 'logout_last_time';
class Cache {
    constructor(keyName, clearAll = true) {
        this.keyName = keyName;
        this.type = 'Cookie';
        this.LoginStatus = false;
        this.clearAll = clearAll;
        this.init();
    }
    hasLogin() {
        this.init();
        return this.LoginStatus;
    }
    getCacheTime() {
        return Number(window.localStorage.getItem(LAST_TIME));
    }
    setCacheTime() {
        const lastTime = new Date().getTime() + '';
        window.localStorage.setItem(LAST_TIME, lastTime);
    }
    removeCache() {
        const keyName = this.keyName;
        const clearAll = this.clearAll;
        const type = this.type;
        switch (type) {
            case 'Cookie':
                api.remove(keyName);
                break;
            case 'LocalStorage':
                localStorage.removeItem(keyName);
                break;
            case 'SessionStorage':
                sessionStorage.removeItem(keyName);
        }
        if (clearAll) {
            clearCookies();
            localStorage.clear();
            sessionStorage.clear();
        }
        location.reload();
    }
    init() {
        const keyName = this.keyName;
        let token = api.get(keyName);
        if (token !== undefined) {
            this.type = 'Cookie';
            this.LoginStatus = true;
        }
        token = localStorage.getItem(keyName);
        if (token !== null) {
            this.type = 'LocalStorage';
            this.LoginStatus = true;
        }
        token = sessionStorage.getItem(keyName);
        if (token !== null) {
            this.type = 'SessionStorage';
            this.LoginStatus = true;
        }
    }
}

class Logout {
    constructor(options) {
        this.keyName = options.keyName || 'token';
        this.enable = options.enable || true;
        this.stagnateTime = options.stagnateTime || 30 * 60 * 1000;
        this.detectTime = options.detectTime || 10 * 1000;
        this.cache = new Cache(this.keyName, options.clearAll);
        this.init();
    }
    start() {
        setInterval(this.detect.bind(this), this.detectTime);
    }
    detect() {
        if (this.enable) {
            const currentTime = new Date().getTime(); // 记录这次点击的时间
            const cache = this.cache;
            const lastTime = cache.getCacheTime.apply(cache);
            // 判断上次最后一次点击的时间和这次点击的时间间隔是否设定停滞时间
            if (currentTime - lastTime > this.stagnateTime) {
                const hasLogin = cache.hasLogin.apply(cache);
                // 如果是登录状态，退出登录
                if (hasLogin) {
                    cache.removeCache.apply(cache);
                }
            }
        }
    }
    init() {
        // 监听页面刷新、鼠标事件、鼠标移动、键盘事件 更新最后一次点击时间
        const cache = this.cache;
        window.onload = function () {
            cache.setCacheTime.apply(cache);
        };
        window.document.onmousedown = function () {
            cache.setCacheTime.apply(cache);
        };
        window.document.onmouseover = function () {
            cache.setCacheTime.apply(cache);
        };
        window.document.onkeydown = function () {
            cache.setCacheTime.apply(cache);
        };
    }
}

const logoutPlugin = {
    install(app, options) {
        const logout = new Logout(options);
        logout.start.call(logout);
        app.directive('logout');
    }
};

export { logoutPlugin as default };
//# sourceMappingURL=vue-auto-logout.es5.js.map
